@@ -13,7 +13,7 @@ import os
 import warnings
 warnings.filterwarnings("ignore", category=SyntaxWarning)
 
-__version__ = "2.0.5"
+__version__ = "2.0.12"
 
 global_options = optparse.OptionParser(
     usage="yoc COMMAND [ARGS]"
@@ -57,8 +57,16 @@ class YocCommand:
             cmd = self.commands[name]
 
         except KeyError:
-            put_string("yoc: '%s' is not a yoc command.  See 'yoc help'." %
-                       name, file=sys.stderr)
+            if not self.conf.init:
+                if name not in all_commands:
+                    put_string("`yoc %s` is not a yoc command." %
+                        name, file=sys.stderr, level='error')
+                else:
+                    put_string("`yoc %s` can only be used in the workspace. Please execute `yoc init` to initialize your workspace first. See `yoc help`." %
+                            name, file=sys.stderr, level='error')
+            else:
+                put_string("`yoc %s` is not a yoc command." %
+                        name, file=sys.stderr, level='error')
             return 1
 
         try:
@@ -66,15 +74,15 @@ class YocCommand:
             copts = cmd.ReadEnvironmentOptions(copts)
         except Exception as e:
             put_string('error: in `%s`: %s' % (' '.join([name] + argv), str(e)),
-                       file=sys.stderr)
+                       file=sys.stderr, level='error')
             put_string('error: manifest missing or unreadable -- please run init',
-                       file=sys.stderr)
+                       file=sys.stderr, level='error')
             return 1
         try:
             cmd.ValidateOptions(copts, cargs)
             result = cmd.Execute(copts, cargs)
         except Exception as e:
-            put_string("YocCommand error:", e)
+            put_string("YocCommand error:%s" % str(e), level='error')
             pass
         return result
 
@@ -91,3 +99,21 @@ def main():
             return
     cmd = YocCommand()
     cmd.Execute(sys.argv[1:])
+
+def cct_main():
+    try:
+        cmd = all_commands['cct']
+        parser = cmd.OptionParser
+        parser.set_usage(cmd.helpUsage.strip().replace('%prog', cmd.NAME))
+        copts, cargs = parser.parse_args(sys.argv[1:])
+        copts = cmd.ReadEnvironmentOptions(copts)
+    except Exception as e:
+        put_string('error: manifest missing or unreadable -- please run init',
+                    file=sys.stderr, level='error')
+        return 1
+    try:
+        cmd.ValidateOptions(copts, cargs)
+        cmd.Execute(copts, cargs)
+    except Exception as e:
+        put_string("YocCommand error:%s" % str(e), level='error')
+        pass
