@@ -46,12 +46,23 @@ class Component:
         self.need_build = True
         self.loaded = False
 
+        self.sdk_chip = [] # # [{'sdk_chip_ch2201':'v7.3'},{'sdk_chip_arm_dummy':'v7.4'}]
+        self.mkflash_script = ''
+
     def check_file_integrity(self):
         readme_file = os.path.join(self.path, 'README.md')
-        if not os.path.exists(readme_file):
-            return False
-        return True
-        
+        package_file = os.path.join(self.path, 'package.yaml')
+        if os.path.isfile(readme_file) and os.path.isfile(package_file):
+            return True
+        return False
+
+    def check_git_integrity(self):
+        if self.check_file_integrity():
+            git_path = os.path.join(self.path, '.git')
+            if os.path.exists(git_path):
+                return True
+        return False
+
     def json_dumps(self):
         dep_names = []
         for item in self.depends:
@@ -97,17 +108,39 @@ class Component:
 
     def download(self, branch=''):
         if True:
+            if self.check_git_integrity():
+               put_string('Component %s is installed, skip to install it. Syncing...' % self.name, level='warning')
+               git = GitRepo(self.path, self.repo_url)
+               git.sync()
+               return
             if self.version:
                 branch = self.version
             elif not branch:
                 branch = 'master'
-            if not self.conf.repo.endswith('.git'):
-                repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
-            if self.repo_url:
-                repo_url = self.repo_url
-            prj = GitRepo(self.path, repo_url)
-            put_string("%-16s(%s), clone %s ..." % (self.name, branch, self.repo_url))
-            prj.pull(branch, None)
+            # if not self.conf.repo.endswith('.git'):
+            #     self.repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
+            if not self.repo_url:
+                put_string('Component repo url "%s" is not existed.' % self.name, level='warning')
+                return
+            if not self.repo_url.endswith('.git'):
+                put_string('The Git URL[%s] is illegal' % self.repo_url, level='warning')
+                return
+
+            git = GitRepo(self.path, self.repo_url)
+            # 如果找不到对应的branch，则clone master分支
+            branches = git.GetRemoteBranches('origin')
+            tags = git.GetRemoteTags('origin')
+            if len(branches) == 0:
+                if len(tags) == 0:
+                    put_string('There is no branch/tag found for component:%s in remote.' % self.name, level='warning')
+                    return
+                branches = tags
+            if branch not in branches and branch not in tags:
+                put_string("%-16s(%s->master), clone %s ..." % (self.name, branch, self.repo_url), level='warning')
+                branch = 'master'
+            else:
+                put_string("%-16s(%s), clone %s ..." % (self.name, branch, self.repo_url))
+            git.pull(branch, None)
 
         elif self.version in self.historyVersion.keys():
             zip_url = self.historyVersion[self.version]
@@ -120,7 +153,7 @@ class Component:
 
     def upload(self, repo_base_url=''):
         if not self.check_file_integrity():
-            put_string("There is no `README.md` file found in %s component,please add it first." % self.name)
+            put_string("There is no `README.md` file found in %s component,please add it first." % self.name, level='error')
             exit(-1)
         repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
         if self.conf.repo.endswith('.git'):
@@ -131,18 +164,18 @@ class Component:
             repo_url = os.path.join(repo_base_url, '%s.git' % self.name)
 
         try:
-            prj = GitRepo('/tmp/' + self.name)
-            prj.set_remote(repo_url)
+            git = GitRepo('/tmp/' + self.name)
+            git.set_remote(repo_url)
             branch = self.version
-            prj.pull(branch)
-            prj.import_path(self.path, branch)
+            git.pull(branch)
+            git.import_path(self.path, branch)
         except:
-            put_string("Component `%s` upload fail." % self.name)
+            put_string("Component `%s` upload fail." % self.name, level='warning')
 
         try:
             shutil.rmtree('/tmp/' + self.name)
         except Exception as e:
-            put_string(e)
+            put_string("%s" % str(e), level='error')
             exit(-1)
 
     def zip(self, path):
@@ -175,24 +208,35 @@ class Component:
         for f in self.source_files:
             put_string('%s%s' % (' '*indent, f))
 
-    def load_package(self):
-        # if self.type:
-        #     return False
+    def depends_illegal_check(self):
+        if not is_legal_depend(self.depends):
+            filename = os.path.join(self.path, 'package.yaml')
+            put_string("Exception in file:%s" % filename, level='error')
+            exit(-1)
 
+    def source_files_check(self):
+        for s in self.source_files:
+            if os.path.isabs(s):
+                filename = os.path.join(self.path, 'package.yaml')
+                put_string("Can't be a absolute path:%s" % s, level='error')
+                put_string("Exception in file:%s" % filename, level='error')
+                exit(-1)
+
+    def check_self(self):
+        self.depends_illegal_check()
+        self.source_files_check()
+
+    def load_package(self):
         if self.loaded:
             return True
 
-        # if not self.check_file_integrity():
-        #     exit(-1)
-
         filename = os.path.join(self.path, 'package.yaml')
         if not os.path.isfile(filename):
             return False
         pack = Package(filename)
         self.pack = pack
         if os.path.basename(self.path) != pack.name:
-            logger.warning(
-                "component `%s`, but the directory is `%s`." % (pack.name, filename))
+            put_string("component `%s`, but the directory is `%s`." % (pack.name, filename), level='warning')
 
         self.name = pack.name
         self.version = pack.version
@@ -208,11 +252,20 @@ class Component:
         self.hw_info = copy.deepcopy(pack.hw_info)
         self.hw_info.update_path(self.path)
         self.need_build = self.type not in ['board', 'chip']
+        self.mkflash_script = os.path.join(self.path, self.pack.mkflash_script)
 
         self.depends = []
         for d in pack.depends:
             if type(d) == dict:
                 self.depends.append(d)
+        # append sdk_chip
+        for d in pack.sdk_chip:
+            if type(d) == dict:
+                self.sdk_chip.append(d)
+                if d not in self.depends:
+                    self.depends.append(d)
+
+        self.check_self()
 
         self.loaded = True
         return True
@@ -372,7 +425,7 @@ class Component:
 
             return True
         except Exception as e:
-            put_string(e)
+            put_string("%s" % str(e), level='error')
             return False
 
 
@@ -419,16 +472,41 @@ class ComponentGroup(list):
 
     def get_depend(self, component, exclude_names=[]):
         arr_non = []
+        dep_list = {} # store {{"aos:v7.4.0":"father":"helloworld"}}
+        vercheck_list = {}  # store different version list {{"aos:v7.4.0":"father":"helloworld"}}
+        def _append_dep_version(component, dep):
+            if type(dep) == dict:
+                name = list(dep.keys())[0]
+                version = list(dep.values())[0]
+                for k, v in dep_list.items():
+                    son = k.split(':')[0]
+                    ver = k.split(':')[1]
+                    if son == name and ver != version:
+                        vercheck_list["%s:%s" % (name, version)] = {"father":component.name}
+                        vercheck_list[k] = v
+                key = "%s:%s" % (name, version)
+                if key not in dep_list:
+                    dep_list[key] = {"father":component.name}
+
+        def _show_vercheck_list(vercheck_list):
+            for k in sorted(vercheck_list):
+                son = k.split(':')[0]
+                ver = k.split(':')[1]
+                father = vercheck_list[k]["father"]
+                put_string("version_check: %s: %s in %s's depends." % (son, ver, father), level='warning')
+
         def _check_depend(component):
             component.load_package()
 
-            for name in component.depends:
-                if type(name) == dict:
-                    name = list(name.keys())[0]
+            for dep in component.depends:
+                name = dep
+                if type(dep) == dict:
+                    name = list(dep.keys())[0]
                 if name not in exclude_names:
+                    _append_dep_version(component, dep)
                     if not self.get(name):
                         if name not in arr_non:
-                            put_string("There is no depend component `%s` found!" % name)
+                            put_string("There is no depend component `%s` found!" % name, level='warning')
                             arr_non.append(name)
 
                     c = self.components.get(name)
@@ -442,6 +520,7 @@ class ComponentGroup(list):
         depends = ComponentGroup()
 
         _check_depend(component)
+        _show_vercheck_list(vercheck_list)
         return depends, len(arr_non) > 0
 
 
