@@ -54,45 +54,45 @@ class HardwareInfo:
         if type == 'chip':
             if len(self.cpu_list) == 0:
                 if not self.cpu_name:
-                    return 'chip component must set chip.cpu_name field'
+                    return 'Chip component must set hw_info.cpu_name field'
                 if not self.vendor_name:
-                    return 'chip component must set chip.vendor_name field'
+                    return 'Chip component must set hw_info.vendor_name field'
                 if not self.ld_script:
-                    return 'chip component must set chip.ld_script field'
+                    return 'Chip component must set hw_info.ld_script field'
                 if not self.flash_program:
                     logger.warn('chip component flash_program field')
             else:
-                for _, v in self.cpu_list.items():
+                for k, v in self.cpu_list.items():
                     if 'cpu_name' in v and (not v['cpu_name']):
-                        return 'chip component must set chip.cpu_name field'
+                        return 'Chip component must set hw_info.%s.cpu_name field' % k
                     if (not self.ld_script) and ('ld_script' in v and (not v['ld_script'])):
-                        return 'chip component must set chip.ld_script field'
+                        return 'Chip component must set hw_info.%s.ld_script field' % k
 
         elif type == 'board':
             if not self.chip_name:
-                return 'board component must set chip.chip_name field'
-        elif type == 'solution':
-            if not (self.board_name or self.chip_name or (self.cpu_name and self.ld_script)):
-                return "Solution must set board_name or chip_name, or must set cpu_name and ld_script"
+                return 'Board component must set hw_info.chip_name field'
+        # elif type == 'solution':
+        #     if not (self.board_name or self.chip_name or (self.cpu_name and self.ld_script)):
+        #         return "Solution must set board_name or chip_name, or must set cpu_name and ld_script"
 
     def update_path(self, path):
         if self.ld_script:
             self.ld_script = os.path.join(path, self.ld_script)
+        if self.flash_program:
+            self.flash_program = os.path.join(path, self.flash_program)
         cpu_list = {}
         for k, v in self.cpu_list.items():
             vv = {}
             for k1, v1 in v.items():
-                if k1 == 'ld_script':
+                if k1 == 'ld_script' or k1 == 'flash_program':
                     v1 = os.path.join(path, v1)
                 vv[k1] = v1
             cpu_list[k] = vv
         self.cpu_list = cpu_list
 
-    def merge(self, info, force=False):
-        for k, v in self.__dict__.items():
-            if force and info.__dict__[k]:
-                self.__dict__[k] = info.__dict__[k]
-            elif not v and info.__dict__[k]:
+    def merge(self, info):
+        for k, _ in self.__dict__.items():
+            if info.__dict__[k]:
                 self.__dict__[k] = info.__dict__[k]
 
     def out(self, hw_key=None):
@@ -112,14 +112,14 @@ class HardwareInfo:
         if self.flash_program:
             text += '  flash_program: {}\n'.format(self.flash_program)
 
-        text_head = '''
+        text_info = '''
 ## 第三部分：板级信息
 # hw_info:                                 # 对 solution、board、chip 三个字段的改进，统称为 hw_info 字段
 #   cpu_id: cpu0
 #   cpu_name: CK804EF
 #   vendor_name: t-head
 #   chip_name: chip_pangu                  # <可选项> 指定芯片组件名,未设置时，使用depends中 chip 第一个组件
-#   board_name: pangu_cpu0                 # <可选项> 指定开发板组件名，未设置时，使用depends中 board 第一个组件
+#   board_name: pangu_cpu0_evb             # <可选项> 指定开发板组件名，未设置时，使用depends中 board 第一个组件
 #   ld_script: configs/gcc_eflash.ld       # <可选项> 连接时使用 LD 脚本，当选把未设置时，使用对应的 board 的 LD 脚本
 #   flash_program: bin/flash_program.elf   # <可选项> 芯片全局烧写程序
 #   toolchain_prefix: csky-abiv2-elf       # <可选项> 编译器前缀
@@ -133,21 +133,28 @@ class HardwareInfo:
 #     ld_script: configs/gcc_eflash.ld     # <可选项> 连接时使用 LD 脚本
 #     flash_program: bin/flash_program.elf # <可选项> 该CPU对应烧写程序，未指定时使用全局烧写程序
 #     toolchain_prefix: csky-abiv2-elf     # <可选项> 编译器前缀
-
+'''
+        if hw_key == 'solution':
+            text_head = '''
 ## solution component
 # hw_info:
 #   cpu_id: cpu0
-#   board_name: pangu_cpu0
+#   board_name: pangu_cpu0_evb
 #   cpu_name: CK805EF
 #   vendor_name: thead
 #   chip_name: 'chip_pangu'
 #   ld_script: configs/gcc_eflash.ld.S
-
+'''
+        elif hw_key == 'board':
+            text_head = '''
 ## board component
 # hw_info:
 #   chip_name: chip_pangu
 #   ld_script: configs/gcc_eflash.ld
+'''
 
+        elif hw_key == 'chip':
+            text_head = '''
 ## chip component (单处理器)
 # hw_info:
 #   cpu_name: CK804EF
@@ -171,9 +178,7 @@ class HardwareInfo:
 
         if text:
             if hw_key in ['board', 'chip', 'solution']:
-                text = text_head + hw_key + ':\n' + text
-            else:
-                text = 'hw_info:\n' + text
+                text = text_info + text_head + 'hw_info:\n' + text
 
         return text
 
@@ -252,12 +257,14 @@ class Package(object):
         self.license = ''
         self.homepage = ''
         self.depends = {}
+        self.sdk_chip = {}
         self.build_config = build_config({})
         self.defconfig = {}
         self.source_file = []
         self.install = []
         self.export = []
         self.hw_info = HardwareInfo({})
+        self.mkflash_script = ''
 
         if filename:
             self.load(filename)
@@ -265,16 +272,16 @@ class Package(object):
     def check_name(self):
         # name
         if not self.name:
-            put_string('%s: `name` cannot be empty!' % self.filename)
+            put_string('%s: `name` field cannot be empty!' % self.filename, level='error')
             return False
         elif is_contain_chinese(self.name):
-            put_string("%s: `name` can't be chinese!" % self.filename)
+            put_string("%s: `name` field can't be chinese!" % self.filename, level='error')
             return False
         elif len(self.name) > 64:
-            put_string("%s: `name` is too long, max length is 64." % self.filename)
+            put_string("%s: `name` field is too long, max length is 64." % self.filename, level='error')
             return False
-        elif not is_leagal_name(self.name):
-            put_string("%s: `name` does not conform to naming conventions." % self.filename)
+        elif not is_legal_name(self.name):
+            put_string("%s: `name` field does not conform to naming conventions." % self.filename, level='error')
             return False
 
         return True
@@ -307,28 +314,26 @@ class Package(object):
                     self.__dict__[k] = v
 
         if had_err:
-            put_string("warning: '%s' config may be err in %s. You may be fix this by using command like `yoc format name of the component`!" % (conf_str, filename))
-
-        if self.type in ['board', 'chip', 'solution']:
-            if self.type not in conf and 'hw_info' not in conf:
-                put_string('%s component must set `type` field' % filename)
-                exit(-1)
+            put_string("warning: '%s' config may be err in %s. You may be fix this by using command like `yoc format name of the component`!" % (conf_str, filename), level='warning')
 
         if not self.check_name():
             exit(-1)
 
         # description
         if not self.description:
-            put_string('%s: `description` cannot be empty!' % filename)
+            put_string('%s: `description` field cannot be empty!' % filename, level='error')
+            exit(-1)
+        if not (type(self.description) == str or (sys.version_info.major == 2 and type(self.description) == unicode)):
+            put_string('%s: `description` field must be a string!' % filename, level='error')
             exit(-1)
         # version FIXME:
         if not self.version:
-            logger.warn('%s: `version` cannot be empty!' % filename)
+            logger.warn('%s: `version` field cannot be empty!' % filename)
             # exit(-1)
 
-        if self.type not in ['solution', 'common', 'board', 'chip', 'sdk', 'sdk_chip']:
+        if self.type not in ['solution', 'common', 'board', 'chip', 'sdk']:
             put_string(
-                '%s: `type` must be "solution" or "common" or "board" or "chip" or "sdk" or "sdk_chip".' % filename)
+                '%s: `type` field must be "solution" or "common" or "board" or "chip" or "sdk".' % filename, level='error')
             exit(-1)
 
         text = self.hw_info.check(self.type)
@@ -355,15 +360,17 @@ class Package(object):
     def dumps(self):
         text = '''
 ## 第一部分： 基础信息
-{name}{version}{description}{type}
-{tag}{keywords}{homepage}{author}{license}
+{name}{version}{description}{type}{tag}{keywords}{homepage}{author}{license}
 ## 第二部分：依赖信息
 #           指定该组件依赖的组件及版本，版本支持条件比较，支持：>=v1.0, >v1.0, ==v1.0, <=v1.0, <v1.0, v1.0
 #           未指定条件时，默认为 ==，如 v1.0 与 ==v1.0
+# sdk_chip:                                # <可选项> 该组件依赖sdk组件，合理的依赖才能保证组件能编译、使用
+#   - sdk_chip_csky_dummy: v7.4.y
+#   - sdk_chip_riscv_dummy: v7.4.y
 # depends:                                 # <可选项> 该组件依赖其他的组件，合理的依赖才能保证组件能编译、使用
 #   - minilibc: v7.2.0
 #   - aos: >=v7.2.0
-{depends}{hw_info}
+{sdk_chip}{depends}{hw_info}
 ## 第四部分：编译连接信息
 # build_config:                            # <可选项> 编译配置项
 #   include:                               # <可选项> 编译时，影响编译器的-I 参数 ,全局有效
@@ -408,7 +415,8 @@ class Package(object):
                 'license', self.license, '# <可选项> 源代码的许可证，要确保所有代码、文件的许可证不冲突。如：MIT，Apache license v2.0，BSD'),
             homepage=self.text_out('homepage', self.homepage),
             type=self.text_out(
-                'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common, sdk, sdk_chip'),
+                'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common, sdk'),
+            sdk_chip=self.sdk_chip_out(),
             depends=self.depends_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
@@ -482,6 +490,17 @@ class Package(object):
 
         return text
 
+    def sdk_chip_out(self):
+        text = ''
+        if len(self.sdk_chip) > 0:
+            text = 'sdk_chip:\n'
+            for d in self.sdk_chip:
+                for k, v in d.items():
+                    text += '  - {}: {}\n'.format(k, v)
+                    break
+
+        return text
+
     def fsource_file_out(self):
         text = ""
         if len(self.source_file) > 0:
@@ -503,13 +522,13 @@ class Package(object):
         notes = {
             'install': '''## 第六部分：安装信息
 # install:
-#   - dest: include/                       # 安装的目的路径 dest是相当路径，通常是相对于YoC SDK 安装目录
+#   - dest: include/                       # 安装的目的路径 dest是相对路径，通常是相对于YoC SDK 安装目录
 #     source:                              # 安装源列表
 #      - src/*.h                           # 支持通配符，相对路径
 ''',
             'export': '''## 第七部分：导出部分
 # export:
-#   - dest: "<SOLUTION_PATH>/generated/data" # 安装的目的路径 dest是相当路径
+#   - dest: "<SOLUTION_PATH>/generated/data" # 安装的目的路径 dest是相对路径
 #     source:                                # 安装源列表
 #       - "bootimgs/boot"
 #       - "bootimgs/tee"
