@@ -19,7 +19,8 @@ import os
 all_commands = {}
 
 
-exclude_cmd = ['branch', 'checkout', 'uninstall', 'cdk', 'sdk']
+exclude_cmd = ['checkout', 'uninstall', 'sdk', 'br2tag', 'protect']   # release
+# exclude_cmd = ['uninstall', 'sdk']                                      # develop
 
 my_dir = os.path.dirname(__file__)
 for py in os.listdir(my_dir):
