@@ -24,7 +24,7 @@ generate current solution SDK.
 
     def Execute(self, opt, args):
         yoc = YoC()
-        solution = yoc.getSolution()
+        solution = yoc.getSolution(not_filter=True)
         if solution:
             solution.install()
             pack = solution.solution_component.pack
@@ -62,7 +62,7 @@ generate current solution SDK.
 
                 put_string("Generate %s SDK successful!" % solution.solution_component.name)
         else:
-            put_string("No solution found in current directory!")
+            put_string("No solution found in current directory!", level='warning')
 
     def rebuild_makefile(self, path, filename):
         filename2 = filename + '.new'
