@@ -40,19 +40,22 @@ Display the detailed compilation information of the current solution.
         p.add_option('-d', '--show-define',
                      dest='show_define', action='store_true',
                      help='show all macro define')
-        p.add_option('-s', '--show-source',
+        p.add_option('-u', '--show-source',
                      dest='show_source', action='store_true',
                      help='show all source code file')
         p.add_option('-b', '--board',
                      dest='board_name', action='store', type='str', default=None,
-                     help='show all source code file')
-
+                     help='specify board name')
+        p.add_option('-s', '--sdk',
+                     dest='sdk_name', action='store', type='str', default=None,
+                     help='specify chip sdk name')
 
     def Execute(self, opt, args):
         yoc = YoC()
-        solution = yoc.getSolution(opt.board_name)
+        not_filter = not (opt.board_name or opt.sdk_name)
+        solution = yoc.getSolution(board_name=opt.board_name, sdk_name=opt.sdk_name, not_filter=not_filter)
         if solution == None:
-            put_string("The current directory is not a solution!")
+            put_string("The current directory is not a solution!", level='error')
             exit(0)
         if opt.show_all:
             opt.show_component = True
