@@ -39,16 +39,16 @@ exist in the manifest.
 
     def _Options(self, p):
         self.jobs = 1
-        p.add_option('--force-sync',
-                     dest='force_sync', action='store_true',
-                     help="overwrite an existing git directory if it needs to "
-                     "point to a different object directory. WARNING: this "
-                     "may cause loss of data")
-        p.add_option('--force-remove-dirty',
-                     dest='force_remove_dirty', action='store_true',
-                     help="force remove projects with uncommitted modifications if "
-                     "projects no longer exist in the manifest. "
-                     "WARNING: this may cause loss of data")
+        # p.add_option('--force-sync',
+        #              dest='force_sync', action='store_true',
+        #              help="overwrite an existing git directory if it needs to "
+        #              "point to a different object directory. WARNING: this "
+        #              "may cause loss of data")
+        # p.add_option('--force-remove-dirty',
+        #              dest='force_remove_dirty', action='store_true',
+        #              help="force remove projects with uncommitted modifications if "
+        #              "projects no longer exist in the manifest. "
+        #              "WARNING: this may cause loss of data")
         p.add_option('-j', '--jobs',
                      dest='jobs', action='store', type='int',
                      help="projects to fetch simultaneously (default %d)" % self.jobs)
@@ -69,10 +69,10 @@ exist in the manifest.
             if os.path.exists(os.path.join(component.path, '.git')):
                 components.add(component)
         if len(components) == 0:
-            put_string("There no git repo found in your workspace.")
+            put_string("There no git repo found in your workspace.", level='error')
             exit(0)
 
-        np = Progress('Fetching projects', len(components))
+        np = Progress('Fetching projects', len(components), print_newline=True, force_show=True)
         task_pool = threadpool.ThreadPool(jobs)
         tasks = []
         for component in components:
@@ -80,10 +80,9 @@ exist in the manifest.
             tasks.append(component)
 
         def thread_execture(component):
-            put_string("Syncing %s" % component.name)
-            component.np.update()
+            component.np.update(msg=component.name)
             git = GitRepo(component.path, component.repo_url)
-            git.pull()
+            git.sync()
 
         requests = threadpool.makeRequests(thread_execture, tasks)
         for req in requests:
