@@ -15,11 +15,11 @@ import codecs
 from .tools import *
 
 
-toolchain_url_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-x86_64-minilibc-20200407.tar.gz"
-toolchain_url_32 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz"
+toolchain_url_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-x86_64-minilibc.tar.gz"
+toolchain_url_32 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc.tar.gz"
 
-rsicv_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64-20200820.tar.gz'
-rsicv_url_32 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-i386-20200820.tar.gz'
+rsicv_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64.tar.gz'
+rsicv_url_32 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-i386.tar.gz'
 
 arm_url_64 = 'http://yoctools.oss-cn-beijing.aliyuncs.com/gcc-arm-none-eabi-9-2020-q2-update-x86_64-linux.tar.gz'
 arm_url_32 = ''
@@ -53,10 +53,16 @@ class ToolchainYoC:
 
         tar_path = '/tmp/' + os.path.basename(toolchain_url)
         if not toolchain_url:
-            put_string("Url is empty!")
+            put_string("Url is empty!", level='error')
             return
         put_string("Start to download toolchain: %s" % arch)
-        wget(toolchain_url, tar_path)
+        try:
+            wget(toolchain_url, tar_path)
+        except Exception as ex:
+            put_string(str(ex), level='error')
+            put_string("Please ensure that your machine connected to the Internet.", level='info')
+            return
+
         put_string("")
         put_string("Start install, wait half a minute please.")
         if tar_path.endswith('.bz2'):
@@ -66,7 +72,7 @@ class ToolchainYoC:
             with tarfile.open(tar_path, 'r:gz') as tar:
                 tar.extractall(toolchain_path)
         else:
-            put_string("%s extra not support." % tar_path)
+            put_string("%s extra not support." % tar_path, level='error')
             return
 
         os.remove(tar_path)
@@ -90,7 +96,7 @@ class ToolchainYoC:
                     except FileExistsError:
                         pass
                     except PermissionError:
-                        put_string("Please use: sudo", ' '.join(sys.argv))
+                        put_string("Please use: sudo", ' '.join(sys.argv), level='error')
                         exit(-1)
                     except Exception as e:
                         pass
@@ -135,7 +141,7 @@ class ToolchainYoC:
             bin_file = self.check_program(arch)
         else:
             if verbose == 1:
-                put_string('warn: the toolchains was installed already, path = %s.' % bin_file)
+                put_string('warn: the toolchains was installed already, path = %s.' % bin_file, level='warning')
         return bin_file
 
     def which(self, cmd):
