@@ -29,21 +29,75 @@ except:
 try:
     import yaml
 except:
-    put_string("\n\nNot found pyyaml, please install: \nsudo pip install pyyaml")
+    put_string("\n\nNot found pyyaml, please install: \nsudo pip install pyyaml", level='error')
     sys.exit(0)
 
+class bcolors:
+    BLACK = '\033[30m'
+    RED = '\033[31m'
+    GREEN = '\033[32m'
+    ORANGE = '\033[33m'
+    BLUE = '\033[34m'
+    MAGENTA = '\033[35m'
+    CYAN = '\033[36m'
+    LIGHTGRAY = '\033[37m'
+    ENDC = '\033[0m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
+
 def is_contain_chinese(check_str):
+    if sys.version_info.major == 2:
+        if type(check_str) == str:
+            check_str = check_str.decode('utf-8')
     zhPattern = re.compile(u'[\u4e00-\u9fa5]+')
     match = zhPattern.search(check_str)
     if match:
         return True
 
-def is_leagal_name(name):
+def is_legal_name(name):
     pattern = re.compile(u'^[_a-zA-Z]\w*$')
     match = pattern.search(name)
     if match:
         return True
 
+def is_legal_depend(depends=[]):
+    return True
+    for d in depends:
+        if type(d) == dict:
+            v = list(d.values())[0]
+            if v not in ['develop', 'master', 'main'] and not v.startswith('v') and not v.startswith('V') and not v.startswith('>= '):
+                put_string("%s is illegal" % str(d), level='error')
+                return False
+    return True
+
+def latest_ver_get(ver1, ver2):
+    if (ver1.startswith('>= v') or ver1.startswith('>= V')) and (ver2.startswith('v') or ver2.startswith('V')):
+        num1s = ver1[4:].split('.')
+        num2s = ver2[1:].split('.')
+        print(num1s, num2s)
+        if len(num1s) == 3 and len(num2s) == 3:
+            a1 = int(num1s[0])
+            b1 = int(num1s[1])
+            c1 = num1s[2]
+            if c1 == 'y':
+                c1 = 1000
+            else:
+                c1 = int(c1)
+            a2 = int(num2s[0])
+            b2 = int(num2s[1])
+            c2 = num2s[2]
+            if c2 == 'y':
+                c2 = 1000
+            else:
+                c2 = int(c2)
+            if a1 < a2:
+                return ver2
+            elif b1 < b2:
+                return ver2
+            elif c1 < c2:
+                return ver2
+            return ver2
+
 def string_len(text):
     L = 0
     R = ''
@@ -57,6 +111,33 @@ def string_len(text):
             L += 1
     return L
 
+def colors_print(text, color=''):
+    if color == 'red':
+        print(bcolors.RED + text + bcolors.ENDC, end=' ')
+    elif color == 'green':
+        print(bcolors.GREEN + text + bcolors.ENDC, end=' ')
+    elif color == 'orange':
+        print(bcolors.ORANGE + text + bcolors.ENDC, end=' ')
+    elif color == 'blue':
+        print(bcolors.BLUE + text + bcolors.ENDC, end=' ')
+    elif color == 'magenta':
+        print(bcolors.MAGENTA + text + bcolors.ENDC, end=' ')
+    elif color == 'cyan':
+        print(bcolors.CYAN + text + bcolors.ENDC, end=' ')
+    elif color == 'lightgray':
+        print(bcolors.LIGHTGRAY + text + bcolors.ENDC, end=' ')
+    else:
+        print(text, end=' ')
+
+def level_print(text, level=''):
+    if level == 'info':
+        colors_print(text, 'green')
+    elif level == 'error':
+        colors_print(text, 'red')
+    elif level == 'warning':
+        colors_print(text, 'orange')
+    else:
+        colors_print(text)
 
 def put_string(*args, **keys):
     for a in args:
@@ -66,6 +147,12 @@ def put_string(*args, **keys):
         if 'key' in keys:
             key = keys['key']
             color_print(a, key=key, end=' ', ignorecase=True)
+        elif 'level' in keys:
+            level = keys['level']
+            level_print(a, level.lower())
+        elif 'color' in keys:
+            color = keys['color']
+            colors_print(a, color.lower())
         else:
             print(a, end=' ')
     print()
@@ -109,7 +196,7 @@ def yaml_load(filename):
             text = fh.read()
             return yaml.safe_load(text)
     except Exception as e:
-        put_string("(%s) in file:%s" % (str(e), filename))
+        put_string("(%s) in file:%s" % (str(e), filename), level='error')
         exit(-1)
 
 
@@ -269,7 +356,7 @@ def write_file(text, filename):
         with codecs.open(filename, 'w', encoding='UTF-8') as f:
             f.write(text)
     except:
-        put_string("Generate %s file failed." % filename)
+        put_string("Generate %s file failed." % filename, level='error')
 
 
 def genSConcript(path):
