@@ -57,14 +57,14 @@ class Configure:
                 elif self.repo.startswith('git@'):  # like 'git@gitlab.alibaba-inc.com:yocopen/manifest.git'
                     self.group = self.repo.split(':')[-1].split('/')[-2]
                 else:
-                    put_string('The repo is wrong!')
+                    put_string('The repo is wrong!', level='warning')
             else:
                 if self.repo.startswith('http'):    # like 'https://gitee.com/yocop'
                     self.group = self.repo.split('/')[-1]
                 elif self.repo.startswith('git@'):  # like 'git@gitlab.alibaba-inc.com:yocopen'
                     self.group = self.repo.split(':')[-1]
                 else:
-                    put_string('The repo is wrong!')
+                    put_string('The repo is wrong!', level='warning')
     def load(self, yoc_file):
         if os.path.isfile(yoc_file):
             conf = yaml_load(yoc_file)
@@ -165,7 +165,7 @@ class YoC:
             if not self.components.add(pack):
                 pre_component = self.components.get(pack.name)
                 put_string('Component `%s` is multiple, first defined in :%s, redifned here: %s, please check!)' %
-                             (pack.name, pre_component.path, pack.path))
+                             (pack.name, pre_component.path, pack.path), level='error')
                 exit(0)
 
     def clone_manifest(self, is_all=False):
@@ -173,11 +173,11 @@ class YoC:
         if not os.path.exists(manifest_path):
             os.mkdir(manifest_path)
         repo_url = self.conf.repo
-        prj = GitRepo(manifest_path, repo_url)
+        git = GitRepo(manifest_path, repo_url)
         if is_all:
-            prj.pull('master', None)
+            git.pull('master', None)
         else:
-            prj.pull(self.conf.branch, None)
+            git.pull(self.conf.branch, None)
 
     def manifest_yaml_parse(self, filename=None):
         if not filename:
@@ -186,7 +186,7 @@ class YoC:
             mani = Manifest(filename)
             return mani
         else:
-            put_string("Can't find %s" % filename)
+            put_string("Can't find %s" % filename, level='warning')
             put_string("Maybe there is no branch(%s) in %s" % (self.conf.branch, self.conf.repo))
 
     def get_name_list(self, group):
@@ -224,16 +224,58 @@ class YoC:
                     depends_on.append(c)
         return depends_on
 
-    def getSolution(self, board_name=None):
+    def getSolution(self, board_name=None, sdk_name=None, not_filter=False):
+        if board_name and sdk_name:
+            put_string("Can't specify BOARD and SDK name at one time.", level='error')
+            exit(-1)
+        board_name_in_sdkchip = []
         for component in self.components:
             if component.path == os.getcwd():
                 component.load_package()
+                if sdk_name or len(component.sdk_chip) > 0:
+                    if not sdk_name:
+                        for name in component.depends:
+                            if type(name) == dict:
+                                name = list(name.keys())[0]
+                                c = self.components.get(name)
+                                if c and c.load_package() and c.type == 'sdk':
+                                    sdk_name = name
+                                    break
+                        if not sdk_name:
+                            sdk_name = list((component.sdk_chip[0]).keys())[0]
+
+                    sdk_comp = self.components.get(sdk_name)
+                    if not sdk_comp:
+                        put_string("Sdk chip component `%s` not found in current workspace, please install it: yoc install %s " %(sdk_name, sdk_name), level='error')
+                        exit(-1)
+                    else:
+                        sdk_comp.load_package()
+                        for name in sdk_comp.depends:
+                            if type(name) == dict:
+                                name = list(name.keys())[0]
+                            c = self.components.get(name)
+                            if c:
+                                c.load_package()
+                                if c.type == 'board':
+                                    board_name_in_sdkchip.append(c.name)
+
+                if len(board_name_in_sdkchip) > 1:
+                    put_string("Sdk chip component `%s` includes multi boards, please check." % sdk_name, level='error')
+                    exit(-1)
+                elif len(board_name_in_sdkchip) == 1:
+                    component.hw_info.board_name = board_name_in_sdkchip[0]
                 if board_name:
                     if self.components.get(board_name):
                         component.hw_info.board_name = board_name
                     else:
-                        put_string("Board component `%s` not found in current workspace, please install it: yoc install %s " %(board_name, board_name))
+                        put_string("Board component `%s` not found in current workspace, please install it: yoc install %s " %(board_name, board_name), level='error')
                         exit(-1)
+                # append current sdk chip components to depends filed.
+                for d in component.sdk_chip:
+                    if d not in component.depends:
+                        if sdk_name == list(d.keys())[0]:
+                            component.depends.append(d)
+
                 # 根据指定的board_name过滤其他的board组件
                 exclude_names = []
                 for name in component.depends:
@@ -243,7 +285,17 @@ class YoC:
                     if c:
                         c.load_package()
                         if c.type == 'board' and name != component.hw_info.board_name:
-                            exclude_names.append(name)
+                            if name not in exclude_names:
+                                exclude_names.append(name)
+                        if sdk_name:
+                            if c.type == 'sdk' and name != sdk_name:
+                                if name not in exclude_names:
+                                    exclude_names.append(name)
+                if not_filter:
+                    exclude_names = []
+                    for d in component.sdk_chip:
+                        if d not in component.depends:
+                            component.depends.append(d)
 
                 components, lost = self.components.get_depend(component, exclude_names)
                 if lost:
@@ -253,9 +305,9 @@ class YoC:
 
                 return solution
 
-    def check_cmpt_download(self, name, update=True, force=False):
-        if self.components.get(name) and not force:
-            put_string("Component `%s` have installed already! Please add -f option to install force!" % name)
+    def check_cmpt_download(self, name, update=True):
+        if self.components.get(name):
+            put_string("Component `%s` have installed already! Skip to install it!" % name, level='warning')
         else:
             if update:
                 self.update()
@@ -264,14 +316,14 @@ class YoC:
                 if component:
                     return component
                 else:
-                    put_string("Can't find component %s." % name)
+                    put_string("Can't find component %s." % name, level='warning')
             else:
-                put_string("There is no component found from server!")
+                put_string("There is no component found from server!", level='warning')
         return None
 
     def download_component(self, name, update=True, force=False):
         if self.components.get(name) and not force:
-            put_string("Component `%s` have installed already! Please add -f option to install force!" % name)
+            put_string("Component `%s` have installed already! Please add -f option to install force!" % name, level='warning')
             return None
         if self.components.get(name) == None or force:
             if update:
@@ -285,7 +337,7 @@ class YoC:
 
                 return depends
             else:
-                put_string("There is no component `%s` found from repo!" % name)
+                put_string("There is no component `%s` found from repo!" % name, level='warning')
 
     def remove_component(self, name):
         component = self.components.get(name)
@@ -313,7 +365,7 @@ class YoC:
         if self.occ == None:
             self.occ = OCC(self.conf)
         if not self.occ.login():
-            put_string("Login OCC failed. Please check your username and password.")
+            put_string("Login OCC failed. Please check your username and password.", level='error')
             return False
         return True
 
@@ -331,11 +383,11 @@ class YoC:
                     if self.occ.upload(version, component.type, zip_file) == 0:
                         put_string("Component %s(%s) upload success!" % (component.name, version))
                     else:
-                        put_string("Component %s(%s) upload failed!" % (component.name, version))
+                        put_string("Component %s(%s) upload failed!" % (component.name, version), level='warning')
                 else:
-                    put_string("It is a git repo,abort to upload.")
+                    put_string("It is a git repo,abort to upload.", level='warning')
             else:
-                put_string("Component %s version is empty!" % (component.name))
+                put_string("Component %s version is empty!" % (component.name), level='warning')
 
     def uploadall(self):
         if self.occ == None:
@@ -349,9 +401,9 @@ class YoC:
                 if self.occ.upload(version, component.type, zip_file) == 0:
                     put_string("Component %s(%s) upload success!" % (component.name, version))
                 else:
-                    put_string("Component %s(%s) upload failed!" % (component.name, version))
+                    put_string("Component %s(%s) upload failed!" % (component.name, version), level='warning')
             else:
-                put_string("Component %s version is empty!" % (component.name))
+                put_string("Component %s version is empty!" % (component.name), level='warning')
 
     def update(self, is_all=False):
         def get_repo_url(remotes, cmp_ele):
@@ -390,6 +442,12 @@ class YoC:
                 pickle.dump(self.occ_components, f)
                 self.conf.save()
 
+    def get_latest_version(self, component):
+        for p in self.default_mani.cmpt_list:
+            if component.name == p.name and len(p.history_ver):
+                latest_ver = latest_ver_get(component.version, p.history_ver[len(p.history_ver) - 1])
+                return latest_ver
+
     def update_version(self, depends=[]):
         for component in self.occ_components:
             for d in depends:
@@ -397,13 +455,17 @@ class YoC:
                     name = list(d.keys())[0]
                     if component.name == name:
                         component.version = list(d.values())[0]
+                        latest_ver = self.get_latest_version(component)
+                        if latest_ver and component.version != latest_ver:
+                            component.version = latest_ver
+                            # print('latest_ver========%s,%s' % (latest_ver, component.name))
                         # print("update %s version:%s" % (component.name, component.version))
                         break
             
     def gitee_update(self):
         self.occ_components = ComponentGroup()
         if not self.conf.gitee_token:
-            put_string("Can't fetch from git repo, please check your `.yoc` file.")
+            put_string("Can't fetch from git repo, please check your `.yoc` file.", level='error')
             return
         put_string("Updating from git...")
         repo = RepoGitee(self.conf.gitee_token, self.conf.group)
